@@ -8,7 +8,7 @@ use App::cpm::Logger;
 use Module::CoreList;
 use Module::Metadata;
 use version;
-our $VERSION = '0.214';
+our $VERSION = '0.290';
 
 sub new {
     my ($class, %option) = @_;
@@ -30,7 +30,8 @@ sub fail {
     my @fail_resolve = sort keys %{$self->{_fail_resolve}};
     my @fail_install = sort keys %{$self->{_fail_install}};
     return if !@fail_resolve && !@fail_install;
-    { resolve => \@fail_resolve, install => \@fail_install };
+    my @name = map { CPAN::DistnameInfo->new($_)->distvname || $_ } @fail_install;
+    { resolve => \@fail_resolve, install => \@name };
 }
 
 sub jobs { values %{shift->{jobs}} }
@@ -117,7 +118,12 @@ sub _calculate_jobs {
                     source => $dist->source,
                     uri => $dist->uri,
                 );
-            } elsif (@need_resolve) {
+            } elsif (@need_resolve and !$dist->deps_registered) {
+                $dist->deps_registered(1);
+                local $self->{logger}->{context} = $dist->distvname;
+                my $msg = sprintf "Found configure dependencies: %s",
+                    join(", ", map { sprintf "%s (%s)", $_->{package}, $_->{version} || 0 }  @need_resolve);
+                $self->{logger}->log($msg);
                 my $ok = $self->_register_resolve_job(@need_resolve);
                 $self->{_fail_install}{$dist->distfile}++ unless $ok;
             } elsif (!defined $is_satisfied) {
@@ -143,7 +149,12 @@ sub _calculate_jobs {
                     distfile => $dist->{distfile},
                     uri => $dist->uri,
                 );
-            } elsif (@need_resolve) {
+            } elsif (@need_resolve and !$dist->deps_registered) {
+                $dist->deps_registered(1);
+                local $self->{logger}->{context} = $dist->distvname;
+                my $msg = sprintf "Found dependencies: %s",
+                    join(", ", map { sprintf "%s (%s)", $_->{package}, $_->{version} || 0 }  @need_resolve);
+                $self->{logger}->log($msg);
                 my $ok = $self->_register_resolve_job(@need_resolve);
                 $self->{_fail_install}{$dist->distfile}++ unless $ok;
             } elsif (!defined $is_satisfied) {
