@@ -2,7 +2,7 @@ package App::cpm::Worker;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.214';
+our $VERSION = '0.290';
 
 use App::cpm::Worker::Installer;
 use App::cpm::Worker::Resolver;
@@ -12,8 +12,16 @@ use Time::HiRes qw(gettimeofday tv_interval);
 
 sub new {
     my ($class, %option) = @_;
+    my $home = $option{home};
+    my $logger = $option{logger} || App::cpm::Logger::File->new("$home/build.log.@{[time]}");
+    %option = (
+        %option,
+        logger => $logger,
+        base => "$home/work",
+        cache => "$home/cache",
+    );
     my $installer = App::cpm::Worker::Installer->new(%option);
-    my $resolver  = App::cpm::Worker::Resolver->new(impl => $option{resolver});
+    my $resolver  = App::cpm::Worker::Resolver->new(%option, impl => $option{resolver});
     bless { %option, installer => $installer, resolver => $resolver }, $class;
 }
 
@@ -33,16 +41,16 @@ sub work {
     }
     my $elapsed = $start ? tv_interval($start) : undef;
     $result ||= { ok => 0 };
-    $job = +{ %$job, %$result };
+    $job->merge($result);
     $self->info($job, $elapsed);
     return $job;
 }
 
 sub info {
     my ($self, $job, $elapsed) = @_;
-    my $type = $job->{type};
+    my $type = $job->type;
     return if !$App::cpm::Logger::VERBOSE && $type ne "install";
-    my $name = $job->{distfile} ? CPAN::DistnameInfo->new($job->{distfile})->distvname : $job->{uri}[0];
+    my $name = $job->distvname;
     my ($message, $optional);
     if ($type eq "resolve") {
         $message = $job->{package};
